#!/bin/bash


#  Slackbuild script for pwmanager
# Author: Mark Tucker
# Created: 
# Changes:
#        Aug 31, 2005 - initial creation

#
#----------------------------------------------------------------------
umask 0022

#----------------------------------------
# include the common functions
#----------------------------------------
if [ -r ./sbuild.functions ]; then
    . ./sbuild.functions
else
    echo Cannot read file `pwd`/sbuild.functions
    echo Exiting....
    echo
    exit
fi

#----------------------------------------
# Set locations for temp directories
#----------------------------------------
# location of source code archive
srcdir=`pwd`/SRC
workdir=`pwd`


#----------------------------------------
# Package variables
#----------------------------------------
source="pwmanager-1.2.3.tar.bz2"
pkgname="pwmanager"
pkgver="1.2.3"
release="1mht"
package="$pkgname-$pkgver-i486-$release.tgz"
realname="Mark Tucker"
echo Package: $package

#----------------------------------------
# setup path variables
#----------------------------------------
set_workdir

# unpack the source
echo Unpacking the source...
tar -xjf $srcdir/$source


cd $builddir

#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS


#----------------------------------------
# Build the package and install
#----------------------------------------
# configure 
conf_opts="--prefix=/opt/kde --enable-kwallet"
run_configure $conf_opts

# make
run_make

# Set target directory
set_target

# install
run_makeinstall


echo finishing install...


# create install dir
mkdir $target/install

#----------------------------------------
# create slack-desc file to install
#----------------------------------------
cat > $target/install/slack-desc << END
         |-----handy-ruler------------------------------------------------------|
$pkgname: $pkgname $pkgver - a secure password manager.
$pkgname:
$pkgname: With PwManager you can easily manage your passwords. PwManager saves 
$pkgname: your passwords blowfish-encrypted in one file, so you have to 
$pkgname: remember only one master-password instead of all. Instead of the 
$pkgname: master-password you can use a chipcard, so you don't have to remember
$pkgname: a password to access the list.
$pkgname:
$pkgname: http://passwordmanager.sourceforge.net
$pkgname:
$pkgname: Packaged by $realname for $slackver / KDE 3.4.2
END


# create documentation directory
create_docdir

# fix group on bin directories.
fix_bingrp

# strip  bin files
strip_bin

# strip lib files
strip_libs

# check for uncompressed man pages
compr_man

# makepkg
create_pkg

exit
